@@ -12,7 +12,7 @@ write new modules on the platform::
 """
 import os
 
-VERSION = '3.2.0'
+VERSION = '3.3.2'
 
 def _get_git_revision(path):
     revision_file = os.path.join(path, 'refs', 'heads', 'master')
@@ -50,6 +50,5 @@ from .commands import *
 from .tasks import *
 from .services import * 
 from .datasets import * 
-from .notebook import *
 from .quality import *
-from . import featurestore, realtime, contrib
+from . import featurestore, realtime, contrib, utils, notebook
