@@ -22,11 +22,25 @@ class QueryExecutorBase(Compute):
     to run queries against backends such as backends such as
     mysql
 
-    Example::
+    Features of transform baseclass include:
 
+        * Support query engines (MySQL, Hive, Presto)
+        * Support templatized execution
+        * Support arbitrary number of queries
+        * Supports a generator function to generate per-interval queries
+
+    Configuration looks like::
+
+        ...
+        "args": {
+            "cleanup": False,
+            "force": True,
+            "names": "all",
+            "start": "2020-08-01",
+            "end": "2020-08-03",
+        }
 
     """
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.name = "QueryExecutorBase"
@@ -75,10 +89,10 @@ class QueryExecutorBase(Compute):
     @classmethod
     def instantiable(cls):
         return False
-    
+
     def preload_clean_args(self, args):
         """
-        Check validtiry of the args
+        Check validity of the args
         """
         args = super().preload_clean_args(args)
 
@@ -118,10 +132,47 @@ class QueryExecutorBase(Compute):
 
     ########################################
     # Specification Handling...
-    ########################################        
+    ########################################
     def get_spec(self):
         """
-        Get query execution specification. 
+        Get query execution specification. Override this
+
+        Returns:
+
+           specs (list): A list of dictionaries. Each dictionary
+                         specifies name, credentials, queries to run
+
+        Example::
+
+           return [
+               {
+                   "name": "roomdb",
+                   "cred": "roomdb",
+                   "queries": [
+                       {
+                           "name": "select_star",
+                           "output": "%(data_root)s/shared/db/select_star/%(dt)s.tsv",
+                           "sql": "%(transform_root)s/SQL/select_star.sql",
+                           "params": {
+                            "alpha": 22
+                           }
+                       }
+                   ]
+               },
+               {
+                   "enable": False,
+                   "name": "hive",
+                   "cred": "hiveserver",
+                   "queries": [
+                       {
+                           "name": "employees",
+                           "output": "%(data_root)s/shared/db/employee/%(dt)s.tsv",
+                           "sql": "%(transform_root)s/SQL/employees.hql",
+                       }
+                   ]
+               }
+           ]
+
         """
         return []
 
@@ -269,7 +320,11 @@ class QueryExecutorBase(Compute):
     # Output
     #############################################################
     def get_output_handler(self, query, params):
+        """
+        Find a handler for the output of the query. This function
+        should be over-ridden to compute the handler dynamically.
 
+        """
         if 'output' not in query:
             raise Exception("Unable to determine output handler. No 'output' in query")
 
@@ -283,15 +338,29 @@ class QueryExecutorBase(Compute):
     #############################################################
     def get_executor(self, specitem, query, credentials):
         """
-        Get executor for a specitem and credentials. Override this
-        to provide your own executors...
+        Get executor for a specitem and credentials. This executor
+        runs the query.
+
+        The executor could be specified within the query,
+        spec, or could default to built-in one based on the
+        credentials and dbtype within.
+
+        Args:
+
+            spec (dict): Specification of the query
+            query (dict): Particular query to execute
+            credentials (dict): Credentials for the backend
+
+        Returns:
+
+            a callable executor
         """
 
         default_executor = None
         if credentials['dbtype'] == 'mysql':
             default_executor = self.mysql_executor
         elif credentials['dbtype'] == 'hive':
-            default_executor = self.hive_executor            
+            default_executor = self.hive_executor
 
         # Executor can be per query or for the entire set
         executor = query.get('executor',
@@ -307,7 +376,18 @@ class QueryExecutorBase(Compute):
         raise Exception("Cant find executor: {}".format(executor))
 
     def mysql_executor(self, specitem, credentials, query, params):
+        """
+        Built in executor for queries against a mysql backend. The output
+        is dumped to a temporary file and then an output handler is called
+        for post-processing.
 
+        Args:
+
+            spec (dict): Specification of the query
+            query (dict): Particular query to execute
+            credentials (dict): Credentials for the backend
+
+        """
         try:
 
             targetdir = None
@@ -420,7 +500,16 @@ class QueryExecutorBase(Compute):
 
     def hive_executor(self, specitem, credentials, query, params):
         """
-        Execute hive queries..
+        Built in executor for queries against a hive backend. The output
+        is dumped to a temporary file and then an output handler is called
+        for post-processing.
+
+        Args:
+
+            spec (dict): Specification of the query
+            query (dict): Particular query to execute
+            credentials (dict): Credentials for the backend
+
         """
         try:
 
@@ -476,8 +565,8 @@ class QueryExecutorBase(Compute):
                 cmd += " -n '{}'".format(user)
 
             if 'password' in config:
-                cmd += " -p '{}'".format(password)    
-                
+                cmd += " -p '{}'".format(password)
+
             # Generate the script to run
             script = """#!/bin/bash\n\n"""
             script += "date\n"
@@ -535,7 +624,22 @@ class QueryExecutorBase(Compute):
     # Generators of parameters
     #########################################################
     def get_generator(self, specitem, query):
+        """
+        Parameters generator. This is useful when a templatized
+        query has to be run against the backend over many
+        days. The output of the generator function is a list of
+        dictionaries each of which is a key-value set for one
+        time window (say a day)
 
+        Args:
+
+            spec (dict): Specification of the query
+            query (dict): Particular query to execute
+
+        Returns:
+
+            a callable generator function
+        """
         generator = query.get('generator',
                               specitem.get('generator',
                                            "generator_daily"))
@@ -549,8 +653,9 @@ class QueryExecutorBase(Compute):
 
     def generator_daily(self, spec, specitem, query):
         """
-        Generate a list of dates (one for each day) between
-        two dates.
+        Built-in function to generate a list of dates (one for each day)
+        between two dates.
+
         """
 
         start = self.args['start']
@@ -633,15 +738,15 @@ class QueryExecutorBase(Compute):
             try:
 
                 itemname = specitem['name']
-                
+
                 enable = specitem.get('enable', True)
                 if not enable:
                     logger.error("Skipping: {}. Not enabled.".format(itemname),
                                  extra={
                                      'transform': self.name
-                                 })                    
+                                 })
                     continue
-                
+
                 # What should we be executing to begin with..?
                 toexecute = []
                 for name in names:
@@ -669,7 +774,7 @@ class QueryExecutorBase(Compute):
                 logger.debug("Completed execution: {}".format(itemname),
                              extra={
                                  'transform': self.name
-                             })                
+                             })
             except:
                 logger.exception("Unable to execute: {}".format(itemname),
                                  extra={
