@@ -14,7 +14,7 @@ class TableSink(Sink):
 
     Parameters specific to this module include:
 
-        * args: A dictionary of dataframe names and how to output them. It has a number of attributes:
+        * sink: A dictionary of dataframe names and how to output them. It has a number of attributes:
 
             * type: Output type. Only 'table' value is supported for this
               option right now.
@@ -28,22 +28,25 @@ class TableSink(Sink):
 
         ....
         "transforms": {
-            "enabled": {
-               ...
-               "TableSink": {
-                  "args": {
-                      "article": {
-                         "frametype": "pandas",
-                         "filename": "%(output)s/%(runid)s/article.csv",
-                         "params": {
-                             "sep": "|"
-                         }
-                      },
-                       ...
-                  }
-               }
-            ...
-           }
+            "enabled": [
+                ...
+                {
+                    "transform": "TableSink",
+                    "args": {
+                        "sink": {
+                            "article": {
+                                "frametype": "pandas",
+                                "filename": "%(output)s/%(runid)s/article.csv",
+                                "params": {
+                                    "sep": "|"
+                                }
+                            },
+                            ...
+                        }
+                    }
+                    ...
+                }
+            ]
          }
     """
     def __init__(self, *args, **kwargs):
@@ -53,15 +56,17 @@ class TableSink(Sink):
         self.testdata = {
             'conf': {
                 'args': {
-                    "cars": {
-                        "frametype": "pandas",
-                        "filename": "%(output)s/cars_revised.csv",
-                        "params": {
-                            "sep": ","
+                    "sink": {
+                        "cars": {
+                            "frametype": "pandas",
+                            "filename": "%(output)s/cars_revised.csv",
+                            "params": {
+                                "sep": ","
+                            }
                         }
                     }
                 }
-	    },
+	        },
             'data': {
                 "carmodel": {
                     "transform": "CarModel",
@@ -91,13 +96,24 @@ class TableSink(Sink):
         above
         """
 
-        args = super().preload_clean_args(args)
-
         # Sanity check...
         assert isinstance(args, dict)
         assert len(args) > 0
 
-        for pattern, detail  in args.items():
+        # Backward compatability
+        if 'sink' not in args:
+            args = {
+                'sink': args
+            }
+
+        args = super().preload_clean_args(args)
+
+        assert 'sink' in args
+        sink = args['sink']
+        assert isinstance(sink, dict)
+        assert len(sink) > 0
+
+        for pattern, detail  in sink.items():
 
             if (("type" in detail) and
                 ("frametype" not in detail) and
@@ -140,8 +156,10 @@ class TableSink(Sink):
         """
         Extra validation of the arguments
         """
-        assert isinstance(self.args, dict)
-        for pattern, detail  in self.args.items():
+        sink = self.args['sink']
+
+        assert isinstance(sink, dict)
+        for pattern, detail  in sink.items():
             assert (('frametype' in detail) and (detail['frametype'] == 'pandas'))
             assert 'filename' in detail
             assert 'params' in detail
@@ -161,7 +179,9 @@ class TableSink(Sink):
         args_input = {}
         framecls = self.config.get_dataframe('pandas')
         skipped = []
-        for pattern in self.args:
+
+        sink = self.args['sink']
+        for pattern in sink:
             # The pattern could be precise dataframe name or could be
             # regular expression.
             regex = re.compile('^{}$'.format(pattern))
@@ -176,7 +196,7 @@ class TableSink(Sink):
                 overrides = self.frame_get_overrides(detail)
 
                 #=> Materialize the path...
-                filename = self.args[pattern]['filename']
+                filename = sink[pattern]['filename']
                 filename = self.config.get_file(filename,
                                                 create_dir=True,
                                                 extra={
@@ -197,12 +217,12 @@ class TableSink(Sink):
                 frametype = detail['frametype']
 
                 # Order the dataframe if it is needed
-                sortcols = self.args[pattern]['sort']
+                sortcols = sink[pattern]['sort']
                 if len(sortcols) > 0:
                     df = framecls.sort_values(df,
                                            sortcols,
                                            ascending=False)
-                params = self.args[pattern].get('params',{})
+                params = sink[pattern].get('params',{})
 
                 # Should I be writing this csv?
                 save = params.get('save', True)
@@ -220,7 +240,7 @@ class TableSink(Sink):
                     'params': params,
                 }
 
-                args_input[f] = copy.copy(self.args[pattern])
+                args_input[f] = copy.copy(sink[pattern])
                 args_input[f]['filename'] = filename
 
         if len(skipped) > 0:
@@ -241,7 +261,7 @@ class TableSink(Sink):
             pattern = detail['pattern']
 
             #
-            detail['params']['tags'] = self.args[pattern]['tags']
+            detail['params']['tags'] = sink[pattern]['tags']
 
             # Incorporate columns, notes and description
             additional_params = extra[name]
@@ -289,5 +309,8 @@ class TableSink(Sink):
                          'transform': self.name
                      }))
 
+    def validate_results(self, what, state):
+        pass
+
 
 provider = TableSink
