@@ -1,4 +1,6 @@
-import os, copy
+import os
+import copy
+import json
 import numpy as np
 from hashlib import sha256
 from datetime import datetime
@@ -14,7 +16,7 @@ class TableSource(Source):
 
     Parameters specific to this module include:
 
-        * args: A dictionary of dataframe names and how to
+        * source: A dictionary of dataframe names and how to
           load them. It has a number of attributes:
 
             * type: Output type. Only 'table' value is
@@ -27,29 +29,31 @@ class TableSource(Source):
 
         ....
         "transforms": {
-            "enabled": {
-               ...
-               "TableSink": {
-                 "args": {
-                     "article": {
-                         "type": "file",
-                         "filename": "%(data)s/ArticleData.csv",
-                         "params": {
-                             "delimiter": "|",
-                             "dtype": {
-                                 "sku": "category",
-                                 "mc_code": "int64",
-                                 "sub_class": "category",
-                                 "priority": "float64"
-                                 ...
-                             }
-                         }
-                      }
+            "enabled": [
+                {
+                    "transform": "TableSink",
+                    "args": {
+                        "source": {
+                            "article": {
+                                "type": "file",
+                                "filename": "%(data)s/ArticleData.csv",
+                                "params": {
+                                    "delimiter": "|",
+                                    "dtype": {
+                                        "sku": "category",
+                                        "mc_code": "int64",
+                                        "sub_class": "category",
+                                        "priority": "float64"
+                                        ...
+                                    }
+                                }
+                            }
+                        }
                       ...
-                  }
-               }
+                    }
+                }
             ...
-           }
+           ]
          }
 
     """
@@ -62,12 +66,20 @@ class TableSource(Source):
         Clean when the spec is loaded...
         """
 
+        # Backward compatability
+        if 'source' not in args:
+            args = {
+                'source': args
+            }
+
         args = super().preload_clean_args(args)
 
         # Sanity check...
         assert isinstance(args, dict)
+        assert 'source' in args
+        assert isinstance(args['source'], dict)
 
-        for name, detail  in args.items():
+        for name, detail  in args['source'].items():
 
             # Insert the frame into the args for backward
             # compatability.
@@ -123,7 +135,8 @@ class TableSource(Source):
         """
         """
         assert isinstance(self.args, dict)
-        for name, detail  in self.args.items():
+        assert 'source' in self.args
+        for name, detail  in self.args['source'].items():
             assert (('frametype' in detail) and (detail['frametype'] == 'pandas'))
             assert 'filename' in detail
             assert 'params' in detail
@@ -131,10 +144,15 @@ class TableSource(Source):
     def sample_inputs(self):
 
         frame = self.config.get_dataframe('pandas')
-        args = self.args
+
+        # Check if nothing has been specified
+        if 'source' not in self.args:
+            return []
+
+        args = self.args['source']
 
         # Read 50 rows only...
-        args = copy.deepcopy(self.args)
+        args = copy.deepcopy(args)
         for name in args:
             if 'params' not in args[name]:
                 args[name]['params'] = {}
@@ -176,7 +194,9 @@ class TableSource(Source):
         # Load all the dataframes. This will use the full enrich
         # deployment's beefed up read function.
         framecls = self.config.get_dataframe('pandas')
-        dfstates = framecls.read(self.args, {})
+        source  = self.args['source']
+
+        dfstates = framecls.read(source, {})
         for dfname, dfstate in dfstates.items():
 
             # => Insert column description
@@ -187,7 +207,7 @@ class TableSource(Source):
             params = dfstate['params']
             if 'filename' in params:
                 filename = params['filename']
-            elif 'filename' in self.args.get(dfname,{}):
+            elif 'filename' in source.get(dfname,{}):
                 filename = self.args[dfname]['filename']
             else:
                 filename = "Unknown"
@@ -229,5 +249,7 @@ class TableSource(Source):
         # Clean the uploaded data...
         self.clean(state)
 
+    def validate_results(self, what, state):
+        pass
 
 provider = TableSource
