@@ -244,7 +244,7 @@ class RunBase(object):
                         type_ = "dataframe"
                         node_transform = last.get(label, generator)
                         node = "{} ({})".format(label, node_transform)
-                        text = "Dataframe: {}".format(detail)
+                        text = "Dataframe: {}".format(text)
                     elif type_ in ['database', 'db', 'databases']:
                         type_ = "database"
                         node_transform = last.get(label, generator)
@@ -659,7 +659,7 @@ class RunManagerBase(object):
             logger.error("RunID ({}) could not be found".format(runid),
                          extra={
                              'transform': self.config.name,
-                             'data': 'Output dirs = {}'.format(", ".join(outputdirs))
+                             'data': 'Output dir(s): {}'.format(", ".join(outputdirs))
                          })
             return
 
@@ -669,10 +669,10 @@ class RunManagerBase(object):
                               rundir=rundir)
             run.load()
             self.runs.append(run)
-            logger.exception("Loaded a new run: {}".format(runid),
-                             extra={
-                                 'transform': self.config.name,
-                             })
+            logger.debug("Loaded a new run: {}".format(runid),
+                         extra={
+                             'transform': self.config.name,
+                         })
         except:
             logger.exception("Unable to load runid: {}".format(runid),
                              extra={
