@@ -2,12 +2,61 @@ import os
 import sys
 import json
 import re
+import traceback
 import pandas as pd
 from s3fs import S3FileSystem
 
+from dateutil import parser as dateparser
 from datetime import datetime, timedelta
 
-class Dataset():
+class DataSource(object):
+    """
+    Class for specifying a dataset. This is a base class
+    meant to be derived and implemented.
+    """
+    def __init__(self, params, *args, **kwargs):
+
+        self._type  = params.get('type', 'unknown')
+        """
+        Type of the dataset.
+        """
+
+        self.name = params['name']
+        """
+        Unique name of the dataset, e.g., Events
+        """
+
+        self.description = params.get('description','')
+        """
+        str: Description
+        Example: "Daily events for Alpha Sensor"
+        """
+
+        self.resolve = kwargs.get('resolve',
+                                  params.get('resolve',{}))
+        """
+        Parameters to resolve paths
+        """
+
+    def set_resolve(self, resolve):
+        """
+        Allow the user to specify a resolving dict
+        """
+        assert isinstance(resolve, dict)
+        assert len(resolve) > 0
+        self.resolve.update(resolve)
+
+    def __str__(self):
+        return "[{}] {}".format(self._type, self.name)
+
+
+class DatabaseTable(DataSource):
+
+    def __init__(self, params, *args, **kwargs):
+        super().__init__(params, *args, **kwargs)
+        self._type = "DBTable"
+
+class Dataset(DataSource):
     """
     Class for specifying a dataset. This is typically
     an input to the transforms.
@@ -18,6 +67,7 @@ class Dataset():
         # there are atleast two sub-datasets
         Dataset(params={
             "name": 'athena-availability',
+            "type": "file",
             "paths": [
                 {
                     "name": "test",
@@ -31,8 +81,8 @@ class Dataset():
                     "path": "%(enrich_data_dir)s/acme/Marketing/shared/datasets/athena/v2/availability",
                 },
                 {
-                    "name": "test",
-                    "nature": "local",
+                    "name": "s3",
+                    "nature": "s3",
                     "path": "%(backup_root)s/%(node)s/data/acme/Marketing/shared/datasets/athena/v2/availability",
                 },
             ],
@@ -59,7 +109,7 @@ class Dataset():
 
     def __init__(self, params, *args, **kwargs):
 
-        super().__init__(*args, **kwargs)
+        super().__init__(params, *args, **kwargs)
 
         # Backward compatability
         if 'paths' not in params:
@@ -74,6 +124,8 @@ class Dataset():
 
         self.validate(params)
 
+        self._type = "File"
+
         self.isfile = params.get('isfile', False)
         """
         Specifies whether the dataset is simple (a file for each
@@ -109,23 +161,6 @@ class Dataset():
         """
 
 
-        self.name = params['name']
-        """
-        Unique name of the dataset, e.g., Events
-        """
-
-        self.description = params.get('description','')
-        """
-        str: Description
-        Example: "Daily events for Alpha Sensor"
-        """
-
-        self.resolve = kwargs.get('resolve',
-                                  params.get('resolve',{}))
-        """
-        Parameters to resolve paths
-        """
-
         self.paths = params.get('paths',{})
         """
         dict: Paths to be resolved
@@ -326,11 +361,6 @@ class Dataset():
     def get_path(self, name, full=False, resolve=None):
         return self.get_path_by_name(name, full, resolve)
 
-    def set_resolve(self, resolve):
-        assert isinstance(resolve, dict)
-        assert len(resolve) > 0
-        self.resolve.update(resolve)
-
     def validate(self, params):
         """
         Validate dataset arguments. It should be a dictionary
@@ -385,9 +415,6 @@ class Dataset():
             raise Exception("Matching requirement {} missing/invalid".format(compare))
 
 
-    def __str__(self):
-        return self.name
-
 
     def generate(self, start, end=None):
         """
@@ -602,38 +629,141 @@ class Dataset():
 
         return results
 
+class Arg():
+    """
+    Dataset command argument
+    """
+
+    def __init__(self, name, description, *args, **kwargs):
+        self.name = name
+        self.description = description
+
+    def find(self, datasource):
+        """
+        Find value values
+        """
+        raise Exception("Not implemented")
+
+    def validate(self, datasource, value):
+        raise Exception("Not implemented")
+
+    def resolve(self, datasource, value,resolve=None):
+        raise Exception("Not implemented")
+
+class DateArg(Arg):
+    """
+    Datetime
+    """
+    def __init__(self, name, *args, **kwargs):
+        super().__init__(name,
+                         "Date within past 1 year",
+                         *args, **kwargs)
+
+    def find(self, datasource):
+        today = datetime.now().date()
+        return today
+
+    def validate(self, datasource, value):
+        today = datetime.now()
+        try:
+            dt = dateparser.parse(value)
+            diff = today - dt
+            if (diff.days > 365) or (diff.days < 0):
+                return False
+            return True
+        except:
+            return False
+
+    def resolve(self, datasource, value, resolve):
+        dt = dateparser.parse(value)
+        return dt
+
+class DatasetPathNatureArg(Arg):
+
+    def __init__(self, name, nature, *args, **kwargs):
+
+        super().__init__(name,
+                         "Path of type: {}".format(nature),
+                         *args, **kwargs)
+        self.nature = nature
+
+    def find(self, datasource):
+
+        valid = []
+        for p in datasource.paths:
+            if (p['nature'] == self.nature):
+                valid.append(p['name'])
+
+        return valid
+
+    def validate(self, datasource, value):
+
+        if not isinstance(datasource, Dataset):
+            return False
+
+        for p in datasource.paths:
+            if ((p['name'] == value) and
+                (p['nature'] == self.nature)):
+                return True
+
+        return False
+
+    def resolve(self, datasource, value,resolve=None):
+
+        if not isinstance(datasource, Dataset):
+            raise Exception("Invalid datasource. Expected dataset")
+
+        return datasource.get_path_by_name(value,resolve=resolve)
+
 def get_commands():
 
-    return [
+    src_s3    = DatasetPathNatureArg("src", "s3")
+    dst_s3    = DatasetPathNatureArg("dst", "s3")
+    src_local = DatasetPathNatureArg("src", "local")
+    dst_local = DatasetPathNatureArg("dst", "local")
+    start     = DateArg("start")
+    end       = DateArg("end")
+
+    commands = [
         {
-            "valid": ['s3', 'local'],
+            "source_type": ['File'],
+            "args": [src_s3, dst_local, start, end],
             "name": "s3-to-local",
+            'description': "Download to local data directory",
             "command": "aws s3 sync s3://%(source)s/%(subdir)s%(slash)s %(destination)s/%(subdir)s%(slash)s",
         },
         {
-            "valid": ['local', 's3'],
+            "source_type": ['File'],
+            "args": [src_local, dst_s3, start, end],
             "name": "local-to-s3",
+            'description': "Upload from local data directory to s3",
             "command": "aws s3 sync %(source)s/%(subdir)s%(slash)s s3://%(destination)s/%(subdir)s%(slash)s",
         },
         {
-            "valid": ['s3', 's3'],
+            "source_type": ['File'],
+            "args": [src_s3, dst_s3, start, end],
             "name": "s3-to-s3",
+            'description': "Sync from one s3 path to another s3 path",
             "command": "aws s3 sync s3://%(source)s/%(subdir)s%(slash)s s3://%(destination)s/%(subdir)s%(slash)s",
         },
         {
-            "valid": ['local', 'remote'],
-            "name": "local-to-remote",
+            "source_type": ['File'],
+            "args": [src_local, dst_local, start, end],
+            "name": "remote-to-local",
+            'description': "Copy from remote local to test",
             "command" : "scp -C -r ubuntu@%(node)s:%(source)s %(destination)s/%(subdir)s"
 
         },
         {
-            "valid": ['remote', 'local'],
+            "source_type": ['File'],
+            "args": [src_local, dst_local, start, end],
             "name": "local-to-remote",
+            'description': "Copy from test to remote local path",
             "command" : "scp -C -r %(destination)s/%(subdir)s ubuntu@%(node)s:%(source)s"
-        }
+        },
     ]
 
-
+    return commands
 
 class DatasetRegistry(object):
     """
@@ -663,16 +793,15 @@ class DatasetRegistry(object):
     def validate(self):
         for c in self.commands:
             assert isinstance(c, dict)
-            assert len(c) > 0
-            assert 'valid' in c
-            assert isinstance(c['valid'], list)
-            assert len(c['valid']) == 2
+            assert (('source_type' in c) and (isinstance(c['source_type'],list)))
+            assert 'args' in c
+            assert isinstance(c['args'], list)
             assert 'name' in c
             assert 'command' in c
             assert isinstance(c['command'], str)
             assert len(c['command']) > 0
 
-    def get_command(self, name):
+    def get_command(self, name, source_type="File"):
         """
         Get the command specification by specifying its name
 
@@ -680,19 +809,22 @@ class DatasetRegistry(object):
             name (str): Name of the command template
         """
         for c in self.commands:
+            if source_type not in c['source_type']:
+                continue
             if c['name'] == name:
                 return c
         raise Exception("Missing command: {}".format(name))
 
-    def get_commands(self):
+    def get_commands(self, source_type='File'):
         """
         Get the command specifications as a list of dicts
 
         """
-        for c in self.commands:
-            if c['name'] == name:
-                return c
-        raise Exception("Missing command: {}".format(name))
+        if source_type is None:
+            return self.commands
+
+        # If specified, then apply that filter..
+        return [c for c in self.commands if source_type in c['source_type']]
 
     def add_datasets(self, items):
         """
@@ -704,11 +836,11 @@ class DatasetRegistry(object):
         """
         if isinstance(items, list):
             for item in items:
-                assert isinstance(item, Dataset)
+                assert isinstance(item, DataSource)
                 item.set_resolve(self.resolve)
             self.datasets.extend(items)
         else:
-            assert isinstance(items, Dataset)
+            assert isinstance(items, DataSource)
             items.set_resolve(self.resolve)
             self.datasets.append(items)
 
@@ -738,7 +870,7 @@ class DatasetRegistry(object):
         """
         List all datasets in the registry
         """
-        return [d.name for d in self.datasets]
+        return [str(d) for d in self.datasets]
 
     def find(self, name):
         """
