@@ -20,7 +20,7 @@ from pythonjsonlogger import jsonlogger
 
 # self
 import enrichsdk
-from enrichsdk import package, datasets, api as sdkapi, lib, featurestore as fslib
+from enrichsdk import package, datasets, api as sdkapi, lib, featurestore as fslib, utils
 
 @click.group()
 def process():
@@ -42,6 +42,10 @@ def process():
     Server:
        api:       Access the server API
 
+    \b
+    Utils:
+       sample:    Sample data for sharing
+
     \b
     Helpers:
        show-log:  Pretty print log output
@@ -68,16 +72,29 @@ def _start(commands):
     print(result)
 
     home = os.environ['HOME']
-    if 'VIRTUAL_ENV' not in os.environ:
-        print("SDK not installed in virtual environment")
-        return
-
     if "ENRICH_ROOT" in os.environ:
         enrich_root = os.environ['ENRICH_ROOT']
     else:
         enrich_root = "$ENRICH_ROOT"
-    venv_root = os.environ['VIRTUAL_ENV']
-    venv_name = os.path.basename(venv_root)
+
+    if 'VIRTUAL_ENV' in os.environ:
+        venv_root = os.environ['VIRTUAL_ENV']
+        venv_name = os.path.basename(venv_root)
+        install_settings = [
+            'echo "#source {}/bin/activate" > $ENRICH_ROOT/env.sh'.format(venv_root),
+            'echo "workon {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
+        ]
+    elif 'CONDA_PREFIX' in os.environ:
+        venv_root = os.environ['CONDA_PREFIX']
+        venv_name = os.path.basename(venv_root)
+        install_settings = [
+            'echo "conda activate {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
+        ]
+    else:
+        print("Please use virtualenvwrapper or conda to install sdk")
+        return
+
+
 
     steps = [
         {
@@ -107,9 +124,8 @@ def _start(commands):
             "description": "[OPTIONAl] Create a simple settings file",
             "cmd": [
                 '# file to be sourced before you start working. use the appropriate',
-                '# environment activation mechanism',
-                'echo "#source {}/bin/activate" > $ENRICH_ROOT/env.sh'.format(venv_root),
-                'echo "workon {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
+                '# environment activation mechanism'
+            ] + install_settings + [
                 'echo "export ENRICH_ROOT={}" >> $ENRICH_ROOT/env.sh'.format(enrich_root)
             ]
         },
@@ -594,6 +610,48 @@ def api(ctx, config):
     ctx.ensure_object(dict)
     ctx.obj['config'] = config
 
+####################################
+# Support for sampling data
+####################################
+@click.group('sample', hidden=True)
+@click.pass_context
+def sample(ctx):
+    """
+    Sample data from blockstores
+    """
+    pass
+
+@sample.command("crawl")
+@click.argument("root")
+@click.option("--ext", default="json",
+              help="Extension of files to look for")
+@click.pass_context
+def crawl(ctx, root, ext):
+    """
+    Crawl the root to find possible files
+
+    Args:
+       root: Path in blockstore with s3:// prefix
+    """
+
+    utils.sample_crawl(root, ext)
+
+@sample.command("cat")
+@click.argument("path")
+@click.pass_context
+def crawl(ctx, path):
+    """
+    Show the contents of path
+
+    Args:
+       path: Path to file in blockstore with s3:// prefix
+    """
+
+    utils.sample_cat(path)
+
+####################################
+# Configure access to server
+####################################
 @click.group()
 @click.pass_context
 def config(ctx):
@@ -1230,6 +1288,7 @@ process.add_command(bootstrap_)
 process.add_command(envsetup)
 process.add_command(api)
 process.add_command(test)
+process.add_command(sample)
 process.add_command(_show_log)
 
 def main():
